Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(172)

Unified Diff: sdk/lib/io/http.dart

Issue 14864009: Keep track of when a socket has been destroyed (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Remove delete_handle marker. Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sdk/lib/_internal/pub/lib/src/safe_http_server.dart ('k') | sdk/lib/io/http_impl.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sdk/lib/io/http.dart
diff --git a/sdk/lib/io/http.dart b/sdk/lib/io/http.dart
index 452dbe7cc4cfa1cc44e50af59b61776d390b4c58..5d316eb7890c5356330b7c30a41fb894f6e9cf5e 100644
--- a/sdk/lib/io/http.dart
+++ b/sdk/lib/io/http.dart
@@ -168,10 +168,13 @@ abstract class HttpServer implements Stream<HttpRequest> {
=> new _HttpServer.listenOn(serverSocket);
/**
* Permanently stops this [HttpServer] from listening for new connections.
* This closes this [Stream] of [HttpRequest]s with a done event.
*/
- void close();
+ Future close();
/**
* Returns the port that the server is listening on. This can be
« no previous file with comments | « sdk/lib/_internal/pub/lib/src/safe_http_server.dart ('k') | sdk/lib/io/http_impl.dart » ('j') | no next file with comments »
@@ -168,10 +168,13 @@ abstract class HttpServer implements Stream<HttpRequest> {
=> new _HttpServer.listenOn(serverSocket);
/**
- * Permanently stops this [HttpServer] from listening for new connections.
- * This closes this [Stream] of [HttpRequest]s with a done event.
+ * Permanently stops this [HttpServer] from listening for new
+ * connections. This closes this [Stream] of [HttpRequest]s with a
+ * done event. The returned future completes when the server is
+ * stopped. For a server started using [bind] or [bindSecure] this
+ * means that the port listened on no longer in use.
*/

Powered by Google App Engine
This is Rietveld 408576698